@@ -67,7 +67,7 @@
   #:use-module ((system foreign) #:prefix ffi:)
 
   #:use-module (ice-9 threads)
-  #:use-module (srfi srfi-1)
+  #:use-module ((srfi srfi-1) #:select (fold))
   #:use-module (srfi srfi-9)
   #:use-module (srfi srfi-9 gnu)
   #:use-module (srfi srfi-43)
@@ -541,8 +541,6 @@
     (if #f #f)))
 
 
-(use-modules (sched))
-
 (define *dbus-sched* (make-scheduler))
 
 (define (dbus-timeout-handler sch timeout)
@@ -573,7 +571,7 @@
 ;; @code{pointer-to} cast for function args.  See @code{epoll_wait} below.
 (define-fh-vector-type struct-epoll_event-vec struct-epoll_event-desc
   struct-epoll_event-vec? make-struct-epoll_event-vec)
-(fh-ref<->deref! struct-epoll_event* make-struct-epoll_event*
+(fh-ref<=>deref! struct-epoll_event* make-struct-epoll_event*
 		 struct-epoll_event-vec make-struct-epoll_event-vec)
 (export make-struct-epoll_event-vec)
 
