@@ -36,7 +36,6 @@
   #:use-module ((srfi srfi-1) #:select (fold fold-right remove lset-union
 					     lset-intersection lset-difference))
   #:use-module ((srfi srfi-9) #:select (define-record-type))
-  #:use-module (srfi srfi-43)
   #:use-module (nyacc util)
   #:use-module (nyacc version)
   #:use-module (ice-9 pretty-print))
@@ -226,15 +225,7 @@
     ((_ <expr> ...)
      (process-spec (lalr-spec-1 <expr> ...)))))
 
-;; @deffn {Procedure} atomize terminal => object
-;; Generate an atomic object for a terminal.   Expected terminals are strings,
-;; characters and symbols.  This will convert the strings @code{s} to symbols
-;; of the form @code{'$:s}.
-;; @end deffn
-(define (atomize terminal)
-  (if (string? terminal)
-      (string->symbol (string-append "$:" terminal))
-      terminal))
+(define atomize atomize-terminal)
 
 ;; @deffn {Procedure} normize terminal => char|symbol
 ;; Normalize a token. This routine will normalize tokens in order to check
@@ -1264,7 +1255,6 @@
       (let* ((term (caar sal))		 ; terminal 
 	     (goto (cdar sal))		 ; target state
 	     (redp (assq term ral))	 ; a-list entry, may be removed
-	     ;;(redl (if redp (cdr redp) #f))) ; reductions on terminal
 	     (redl (and=> redp cdr)))	; reductions on terminal
 	(cond
 	 ((and redl (pair? (cdr redl)))
