@@ -371,8 +371,8 @@
        (pair-for-each
 	(lambda (dsl)
 	  (case (sx-tag (car dsl))
-	    ((stor-spec) (sf "~A" (car (sx-ref (car dsl) 1))))
-	    ((type-qual) (sf "~A" (sx-ref (car dsl) 1)))
+	    ((stor-spec) (sf "~A" (sx-tag (sx-ref (car dsl) 1))))
+	    ((type-qual) (sf "~A" (sx-tag (sx-ref (car dsl) 1))))
 	    ((fctn-spec) (sf "~A" (sx-ref (car dsl) 1)))
 	    ((type-spec) (ppx (car dsl)))
 	    ((typeof-expr typeof-type)
@@ -549,7 +549,7 @@
 
       ;; initializer
       ((initzer ,expr)
-       (sf " = ") (ppx expr))
+       (sf "= ") (ppx expr))
       
       ;; initializer-list
       ((initzer-list . ,items)
@@ -763,7 +763,7 @@
        (pretty-print tree #:per-line-prefix "  ")
        )))
 
-  (if (not (pair? tree)) (throw 'c99-error "pprint: expecing sxml tree"))
+  (if (not (pair? tree)) (throw 'c99-error "pprint: expecting sxml tree"))
   (ppx tree)
   (if ugly (newline)))
 
