@@ -1,6 +1,6 @@
 ;;; nyacc/lex.scm
 
-;; Copyright (C) 2015-2020 - Matthew R.Wette
+;; Copyright (C) 2015-2021 - Matthew R.Wette
 ;; 
 ;; This library is free software; you can redistribute it and/or modify it
 ;; under the terms of the GNU Lesser General Public License as published by
@@ -37,7 +37,7 @@
 
 (define-module (nyacc lex)
   #:export (make-lexer-generator
-	    make-ident-reader
+	    make-ident-reader make-ident-keyword-reader
 	    make-comm-reader
 	    make-string-reader
 	    make-chseq-reader
@@ -172,6 +172,24 @@
 		   (eval-reader reader s)
 		   #t)))
 
+
+;; @deffn {Procedure} make-ident-keyword-reader ident-reader match-table [tval]
+;; Generate a procedure from an ident reader and a parser match-table
+;; that takes a character and returns @code{#f} or a pair for the parser.
+;; The pairs are of the form @code{($ident . "abc")} or @code{(if . "if")}.
+;; The optional token is @code{'$ident}.
+;; @end deffn
+(define* (make-ident-keyword-reader ident-reader match-table
+				    #:optional (tval '$ident))
+  (let ((ident-like? (make-ident-like-p ident-reader))
+	(ident-id (assoc-ref match-table tval)))
+    (let loop ((kt '()) (mt match-table))
+      (if (null? mt)
+	  (lambda (ch)
+	    (and=> (ident-reader ch)
+		   (lambda (s) (cons (or (assoc-ref kt s) ident-id) s))))
+	  (loop (if (ident-like? (caar mt)) (cons (car mt) kt) kt) (cdr mt))))))
+	 
 ;; @deffn {Procedure} read-c-ident ch => #f|string
 ;; If ident pointer at following char, else (if #f) ch still last-read.
 ;; @end deffn
@@ -195,19 +213,7 @@
 ;; @end deffn
 (define like-c$-ident? (make-ident-like-p read-c$-ident))
 
-(define (old-make-string-reader delim) ;; #:xxx
-  (lambda (ch)
-    (if (eq? ch delim)
-	(let loop ((cl '()) (ch (read-char)))
-	  (cond ((eq? ch #\\)
-		 (let ((c1 (read-char)))
-		   (if (eq? c1 #\newline)
-		       (loop cl (read-char))
-		       (loop (cons* c1 cl) (read-char)))))
-		((eq? ch delim) (cons '$string (lxlsr cl)))
-		(else (loop (cons ch cl) (read-char)))))
-	#f)))
-;; @deffn {Procedure} make-string-reader delim
+;; @deffn {Procedure} make-string-reader delim [tval]
 ;; Generate a reader for strings for delimiter.  @var{delim} can be a char
 ;; or a list.  Closing quote escaped with @code{\} is skipped.
 ;; @example
@@ -215,7 +221,7 @@
 ;; @end example
 ;; Pretty printers should be set up to stuff things back.
 ;; @end deffn
-(define (make-string-reader delim)
+(define* (make-string-reader delim #:optional (tval '$string))
   (define (fail) (throw 'nyacc-error "eof reading string"))
   (define (doit nd)
     (let loop ((cl '()) (ch (read-char)))
@@ -228,7 +234,7 @@
 		;;((char=? c1 #\n) (loop (cons #\newline cl) (read-char)))
 		;;((char=? c1 #\r) (loop (cons #\return cl) (read-char)))
 		(else (loop (cons* c1 #\\ cl) (read-char))))))
-	    ((char=? ch nd) (cons '$string (lxlsr cl)))
+	    ((char=? ch nd) (if tval (cons tval (rls cl)) (rls cl)))
 	    (else (loop (cons ch cl) (read-char))))))
   (if (char? delim)
       (lambda (ch) (and (char=? ch delim) (doit ch)))
@@ -304,11 +310,11 @@
 ;; ??=->#, ??/->\, ??'->^, ??(->[, ??)->], ??~->|, ??<->{, ??>->}, ??-->~
 ;; and digraphs <:->[, :>->], <%->{ %>->} %:->#
 ;; @end deffn
-(define (read-c-string ch)
+(define* (read-c-string ch #:optional (tval '$string))
   (if (not (eq? ch #\")) #f
       (let loop ((cl '()) (ch (read-char)))
 	(cond ((eq? ch #\\) (loop (c-escape cl) (read-char)))
-	      ((eq? ch #\") (cons '$string (lxlsr cl)))
+	      ((eq? ch #\") (if tval (cons tval (rls cl)) (rls cl)))
 	      (else (loop (cons ch cl) (read-char)))))))
 
 ;; @deffn {Procedure} make-chlit-reader
