@@ -1,6 +1,6 @@
 ;;; nyacc/parse.scm
 
-;; Copyright (C) 2014-2020 Matthew R. Wette
+;; Copyright (C) 2014-2021 Matthew R. Wette
 ;;
 ;; This library is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU Lesser General Public
@@ -99,7 +99,7 @@
 	  (cdr nval))
 	 ((not (or nval lval))
 	  (if (eqv? '$default (caar (vector-ref pat-v (car state))))
-	      (loop state stack (cons '$default #f) lval) ; default reduction
+	      (loop state stack (cons-source stack '$default #f) lval)
 	      (loop state stack nval (lexr))))		  ; reload
 	 (else
 	  (let* ((laval (or nval lval))
@@ -119,17 +119,30 @@
 	     ((eq? 'reduce (car stx))	; reduce
 	      (let* ((gx (cdr stx))
 		     (gl (vector-ref len-v gx))
-		     ($$ (apply (vector-ref xct-v gx) stack)))
-		(loop (list-tail state gl)
-		      (list-tail stack gl)
-		      (cons (vector-ref rto-v gx) $$)
-		      lval)))
+		     ($$ (apply (vector-ref xct-v gx) stack))
+		     (pobj (if (zero? gl) laval (list-tail stack (1- gl))))
+		     (pval (source-properties pobj))
+		     (tval (cons-source pobj (vector-ref rto-v gx) $$)))
+		(if (supports-source-properties? $$)
+		    (set-source-properties! $$ pval))
+		(loop (list-tail state gl) (list-tail stack gl) tval lval)))
 	     ((eq? 'shift (car stx))	; shift
-	      (loop (cons (cdr stx) state) (cons sval stack)
+	      (loop (cons (cdr stx) state) (cons-source laval sval stack)
 		    #f (if nval lval #f)))
 	     (else			; accept
 	      (car stack))))))))))
 
+;; source property strategy:
+;; lexemes (i.e., token-value pairs) have source properties
+;; as the values are shifted onto @var{stack} the source properties
+;; are attached to the cons cells connecting the elements.
+;; when a reduction occurs, the srcprop for the left-most reduced
+;; value is attached to the return so
+;;    $n $n-1 ... $1 $0 $-1 $-2 ...
+;; red
+;;    $$ | $0 $-1 $-2 ...
+;; (src-prop $1) applied to $$
+
 (define* (make-lalr-parser/num mach #:key (skip-if-unexp '()) interactive env)
   (let* ((len-v (assq-ref mach 'len-v))
 	 (rto-v (assq-ref mach 'rto-v))
@@ -149,7 +162,7 @@
 	  (cdr nval))
 	 ((not (or nval lval))
 	  (if (eqv? $default (caar (vector-ref pat-v (car state))))
-	      (loop state stack (cons $default #f) lval) ; default reduction
+	      (loop state stack (cons-source stack $default #f) lval)
 	      (loop state stack nval (lexr))))		 ; reload
 	 (else
 	  (let* ((laval (or nval lval))
@@ -169,13 +182,16 @@
 	     ((negative? stx)		; reduce
 	      (let* ((gx (abs stx))
 		     (gl (vector-ref len-v gx))
-		     ($$ (apply (vector-ref xct-v gx) stack)))
-		(loop (list-tail state gl)
-		      (list-tail stack gl)
-		      (cons (vector-ref rto-v gx) $$)
-		      lval)))
+		     ($$ (apply (vector-ref xct-v gx) stack))
+		     (pobj (if (zero? gl) laval (list-tail stack (1- gl))))
+		     (pval (source-properties pobj))
+		     (tval (cons-source pobj (vector-ref rto-v gx) $$)))
+		(if (supports-source-properties? $$)
+		    (set-source-properties! $$ pval))
+		(loop (list-tail state gl) (list-tail stack gl) tval lval)))
 	     ((positive? stx)		; shift
-	      (loop (cons stx state) (cons sval stack) #f (if nval lval #f)))
+	      (loop (cons stx state) (cons-source laval sval stack) 
+		    #f (if nval lval #f)))
 	     (else			; accept
 	      (car stack))))))))))
 
@@ -212,7 +228,11 @@
 ;; @end table
 ;; @noindent
 ;; @end deffn
-(define* (make-lalr-parser mach #:key (skip-if-unexp '()) interactive env)
+(define* (make-lalr-parser mach
+			   #:key
+			   (skip-if-unexp '())
+			   interactive
+			   env)
   "- Procedure: make-lalr-parser mach [options] => parser
      Generate a procedure for parsing a language, where MACH is a
      machine generated by 'make-lalr-machine'.  This generates a
@@ -241,18 +261,17 @@
   ;; BUG: this should fail if rrconf exists.
 
   (let* ((mtab (assq-ref mach 'mtab))
-	 (siu (map (lambda (n) (assoc-ref mtab n)) skip-if-unexp))
-	 (iact interactive))
+	 (siu (map (lambda (n) (assoc-ref mtab n)) skip-if-unexp)))
     (if (number? (caar (vector-ref (assq-ref mach 'pat-v) 0)))
 	;; hashed:
 	(make-lalr-parser/num mach
 			      #:skip-if-unexp siu
-			      #:interactive iact
+			      #:interactive interactive
 			      #:env env)
 	;; not hashed:
 	(make-lalr-parser/sym mach
 			      #:skip-if-unexp siu
-			      #:interactive iact
+			      #:interactive interactive
 			      #:env env))))
 
 ;;; --- last line ---
