@@ -1,6 +1,6 @@
 ;;; nyacc/util.scm
 
-;; Copyright (C) 2014-2017 Matthew R. Wette
+;; Copyright (C) 2014-2017,2021 Matthew R. Wette
 ;;
 ;; This library is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU Lesser General Public
@@ -20,6 +20,7 @@
 (define-module (nyacc util)
   #:export (fixpoint
 	    fmtstr fmtout fmterr fmt
+	    atomize-terminal
 	    wrap-action
 	    obj->str
 	    prune-assoc
@@ -27,8 +28,8 @@
 	    x-flip x-comb
 	    write-vec
 	    ugly-print
-	    tzort)
-  #:use-module ((srfi srfi-43) #:select (vector-fold)))
+	    tzort
+	    vector-map vector-for-each vector-any vector-fold))
 (cond-expand
   (mes)
   (guile-2)
@@ -45,6 +46,59 @@
   (apply simple-format (current-error-port) fmt args))
 (define fmt simple-format)
 
+;; replacement for same from (srfi srfi-43)
+(define (vector-map proc . vecs)
+  (let* ((size (apply min (map vector-length vecs)))
+	 (retv (make-vector size)))
+    (let loop ((ix 0))
+      (cond
+       ((= ix size) retv)
+       (else
+	(vector-set! retv ix
+		     (apply proc ix (map (lambda (v) (vector-ref v ix)) vecs)))
+	(loop (1+ ix)))))))
+
+;; replacement for same from (srfi srfi-43)
+(define (vector-for-each proc . vecs)
+  (let ((size (apply min (map vector-length vecs))))
+    (let loop ((ix 0))
+      (cond
+       ((= ix size) (if #f #f))
+       (else
+	(apply proc ix (map (lambda (v) (vector-ref v ix)) vecs))
+	(loop (1+ ix)))))))
+
+;; hack to replace same from (srfi srfi-43)
+;; the real one takes more args
+(define (vector-any pred? vec)
+  (let ((size (vector-length vec)))
+    (let loop ((ix 0))
+      (cond
+       ((= ix size) #f)
+       ((pred? ix (vector-ref vec ix)) #t)
+       (else (loop (1+ ix)))))))
+
+;; replacement for same from (srfi srfi-43)
+(define (vector-fold proc seed . vecs)
+  (let ((size (apply min (map vector-length vecs))))
+    (let loop ((seed seed) (ix 0))
+      (cond
+       ((= ix size) seed)
+       (else
+	(loop
+	 (apply proc ix seed (map (lambda (v) (vector-ref v ix)) vecs))
+	 (1+ ix)))))))
+
+;; @deffn {Procedure} atomize-terminal terminal => object
+;; Generate an atomic object for a terminal.   Expected terminals are strings,
+;; characters and symbols.  This will convert the strings @code{s} to symbols
+;; of the form @code{'$:s}.
+;; @end deffn
+(define (atomize-terminal terminal)
+  (if (string? terminal)
+      (string->symbol (string-append "$:" terminal))
+      terminal))
+
 ;; @deffn {Procedure} make-arg-list N => '($N $Nm1 $Nm2 ... $1 . $rest)
 ;; This is a helper for @code{mkact}.
 ;; @end deffn
